#
# spec file for package python-networkx
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-networkx
Version:        1.10
Release:        4.3
Summary:        Python package for the creation, manipulation,
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://networkx.lanl.gov
Source:         http://pypi.python.org/packages/source/n/networkx/networkx-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-PyYAML
BuildRequires:  python-decorator >= 3.4.0
BuildRequires:  python-devel
BuildRequires:  python-numpy-devel
BuildRequires:  python-pydot
BuildRequires:  python-pyparsing
BuildRequires:  python-setuptools
#don't use non available deps on SLES
%if 0%{?suse_version} && 0%{?suse_version} != 1110 && 0%{?suse_version} != 1315
BuildRequires:  python-matplotlib
BuildRequires:  python-scipy
%endif
Requires:       python-decorator >= 3.4.0
# Recommends: is not understood by redhat's RPM version
%if 0%{?suse_version}
Recommends:     python-pydot
Recommends:     python-pygraphviz
Recommends:     python-PyYAML
Recommends:     python-pyparsing
Recommends:     python-numpy
%if 0%{?suse_version} && 0%{?suse_version} != 1110 && 0%{?suse_version} != 1315
Recommends:     python-matplotlib
Recommends:     python-scipy
%endif
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
NetworkX (NX) is a Python package for the creation, manipulation, and study of the structure, dynamics,
and functions of complex networks.

Features:
 * Includes standard graph-theoretic and statistical physics functions
 * Easy exchange of network algorithms between applications, disciplines, and platforms
 * Includes many classic graphs and synthetic networks
 * Nodes and edges can be "anything" (e.g. time-series, text, images, XML records)
 * Exploits existing code from high-quality legacy software in C, C++, Fortran, etc.
 * Open source (encourages community input)
 * Unit-tested

%prep
%setup -q -n networkx-%{version}
sed -i -e "s@share/doc/networkx-.*@%{_docdir}/%{name}'@g" setup.py
# _docdir contains absolute path, strip /usr/ prefix again
sed -i -e "/^docdirbase/s@/usr/@@" setup.py
find networkx/ examples/ -name "*.py" -exec sed -i -e  '/^#!\s\?\/usr\/bin\/\(env\s\)\?python$/d' {} ';'
sed -i 's/\r//' examples/algorithms/hartford_drug.edgelist

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root %{buildroot}
rm -r %{buildroot}%{_docdir}/%{name}/INSTALL.txt # Makes no sense
%fdupes -s %{buildroot}

%files
%defattr(-,root,root)
%{_docdir}/%{name}
%{python_sitelib}/networkx/
%{python_sitelib}/networkx-%{version}-py*.egg-info

%changelog
* Wed Sep  9 2015 tbechtold@suse.com
- update to 1.10:
  * connected_components, weakly_connected_components, and
    strongly_connected_components return now a generator of
    sets of nodes. Previously the generator was of lists of
    nodes. This PR also refactored the connected_components
    and weakly_connected_components implementations making them
    faster, especially for large graphs.
  * The func_iter functions in Di/Multi/Graphs classes are slated
    for removal in NetworkX 2.0 release. func will behave like func_iter
    and return an iterator instead of list. These functions are deprecated
    in NetworkX 1.10 release.
  * A enumerate_all_cliques function is added in the clique package
    (networkx.algorithms.clique) for enumerating all cliques
    (including nonmaximal ones) of undirected graphs.
  * A coloring package (networkx.algorithms.coloring) is created for graph
    coloring algorithms. Initially, a greedy_color function is provided
    for coloring graphs using various greedy heuristics.
  * A new generator edge_dfs, added to networkx.algorithms.traversal, implements
    a depth-first traversal of the edges in a graph. This complements
    functionality provided by a depth-first traversal of the nodes in
    a graph. For multigraphs, it allows the user to know precisely which
    edges were followed in a traversal. All NetworkX graph types are
    supported. A traversal can also reverse edge orientations or ignore them.
  * A find_cycle function is added to the networkx.algorithms.cycles package
    to find a cycle in a graph. Edge orientations can be optionally
    reversed or ignored.
  * Add a random generator for the duplication-divergence model.
  * A new networkx.algorithms.dominance package is added for dominance/dominator
    algorithms on directed graphs. It contains a immediate_dominators
    function for computing immediate dominators/dominator trees and a
    dominance_frontiers function for computing dominance frontiers.
  * The GML reader/parser and writer/generator are rewritten to remove
    the dependence on pyparsing and enable handling of arbitrary graph data.
  * The network simplex method in the networkx.algorithms.flow package is
    rewritten to improve its performance and support multi- and disconnected
    networks. For some cases, the new implementation is two or three orders
    of magnitude faster than the old implementation.
  * Added the Margulis--Gabber--Galil graph to networkx.generators.
  * Added the chordal p-cycle graph, a mildly explicit algebraic construction of
    a family of 3-regular expander graphs. Also, moves both the existing
    expander graph generator function (for the Margulis-Gabber-Galil expander)
    and the new chordal cycle graph function to a new module,
    networkx.generators.expanders.
  * Allow overwriting of base class dict with dict-like: OrderedGraph, ThinGraph,
    LogGraph, etc.
  * Added to_pandas_dataframe and from_pandas_dataframe.
  * Added the Hopcroft--Karp algorithm for finding a maximum cardinality
    matching in bipartite graphs.
  * Expanded data keyword in G.edges and added default keyword.
  * Added support for finding optimum branchings and arborescences.
  * Added a from_pandas_dataframe function that accepts Pandas DataFrames
    and returns a new graph object. At a minimum, the DataFrame must have two
    columns, which define the nodes that make up an edge. However, the function
    can also process an arbitrary number of additional columns as edge
    attributes, such as 'weight'.
  * Expanded layout functions to add flexibility for drawing subsets of nodes
    with distinct layouts and for centering each layout around given coordinates.
  * Added ordered variants of default graph class.
  * Added harmonic centrality to network.algorithms.centrality.
  * The generators.bipartite have been moved to algorithms.bipartite.generators.
    The functions are not imported in the main namespace, so to use it,
    the bipartite package has to be imported.
  * Added Kanevsky's algorithm for finding all minimum-size separating node
    sets in an undirected graph. It is implemented as a generator of node
    cut sets.
  * Added power function for simple graphs
  * Added fast approximation for node connectivity based on White and Newman's
    approximation algorithm for finding node independent paths between two nodes.
  * Added transitive closure and antichains function for directed acyclic graphs
    in algorithms.dag. The antichains function was contributed by Peter Jipsen
    and Franco Saliola and originally developed for the SAGE project.
  * Added generator function for the complete multipartite graph.
  * Added nonisomorphic trees generator.
  * Added a generator function for circulant graphs to the
    networkx.generators.classic module.
  * Added function for computing quotient graphs; also created a new module,
    networkx.algorithms.minors.
  * Added longest_path and longest_path_length for DAG.
  * Added node and edge contraction functions to networkx.algorithms.minors.
  * Added a new modularity matrix module to networkx.linalg, and associated
    spectrum functions to the networkx.linalg.spectrum module.
  * Added function to generate all simple paths starting with the shortest ones
    based on Yen's algorithm for finding k shortest paths at
    algorithms.simple_paths.
  * Added the directed modularity matrix to the
    networkx.linalg.modularity_matrix module.
  * Adds triadic_census function; also creates a new module,
    networkx.algorithms.triads.
  * Adds functions for testing if a graph has weighted or negatively weighted
    edges. Also adds a function for testing if a graph is empty. These are
    is_weighted, is_negatively_weighted, and is_empty.
  * Added Johnson's algorithm; one more algorithm for shortest paths. It solves
    all pairs shortest path problem. This is johnson at
    algorithms.shortest_paths
  * Added Moody and White algorithm for identifying k_components in a graph,
    which is based on Kanevsky's algorithm for finding all minimum-size node
    cut-sets (implemented in all_node_cuts #1391).
  * Added fast approximation for k_components to the
    networkx.approximation package. This is based on White and Newman
    approximation algorithm for finding node independent paths between two
    nodes (see #1405).
  * The legacy ford_fulkerson maximum flow function is removed.
    Use edmonds_karp instead.
  * Support for Python 2.6 is dropped.
* Sat Jul 25 2015 seife+obs@b1-systems.com
- fix rhel build by conditionalizing "Recommends:" tags
- do not hardcode /usr/share/doc/packages but use %%_docdir
* Wed Apr 29 2015 tbechtold@suse.com
- Don't BuildRequires python-pygraphviz. It's not needed.
* Thu Oct 30 2014 tbechtold@suse.com
- update to version 1.9.1:
  * Bugfix release for minor installation and documentation issues
- Don't BuildRequire/Recommend matplotlib and scipy on SLE11
  and SLE12. Both are not available there.
* Fri Oct 24 2014 toddrme2178@gmail.com
- Add python-decorator in requires to buildrequires
* Mon Sep 15 2014 tbechtold@suse.com
- update to version 1.9:
  * The flow package (networkx.algorithms.flow) is completely rewritten
    with backward incompatible changes. It introduces a new interface
    to flow algorithms. Existing code that uses the flow package will
    not work unmodified with NetworkX 1.9.
  * We added two new maximum flow algorithms (preflow_push and
    shortest_augmenting_path) and rewrote All maximum flow algorithm
    implementations (including the legacy ford_fulkerson) output now
    a residual network (i.e., a DiGraph) after computing the maximum
    flow. See maximum_flow documentation for the details on the
    conventions that NetworkX uses for defining a residual network.
  * We removed the old max_flow and min_cut functions. The main entry
    points to flow algorithms are now the functions maximum_flow,
    maximum_flow_value, minimum_cut and minimum_cut_value, which have
    new parameters that control maximum flow computation: flow_func
    for specifying the algorithm that will do the actual computation
    (it accepts a function as argument that implements a maximum flow
    algorithm), cutoff for suggesting a maximum flow value at which the
    algorithm stops, value_only for stopping the computation as soon as
    we have the value of the flow, and residual that accepts as argument
    a residual network to be reused in repeated maximum flow computation.
  * All flow algorithms are required to accept arguments for these parameters
    but may selectively ignored the inapplicable ones. For instance,
    preflow_push algorithm can stop after the preflow phase without computing
    a maximum flow if we only need the flow value, but both edmonds_karp and
    shortest_augmenting_path always compute a maximum flow to obtain the
    low value.
  * The new function minimum_cut returns the cut value and a node partition
    that defines the minimum cut. The function minimum_cut_value returns
    only the value of the cut, which is what the removed min_cut function
    used to return before 1.9.
  * The functions that implement flow algorithms (i.e., preflow_push,
    edmonds_karp, shortest_augmenting_path and ford_fulkerson) are not
    imported to the base NetworkX namespace. You have to explicitly import
    them from the flow package.
  * We also added a capacity-scaling minimum cost flow algorithm: capacity
    scaling. It supports MultiDiGraph and disconnected networks.
- Add python-decorator as Requires
* Mon Dec  9 2013 toddrme2178@gmail.com
- Add optional dependencies as Recommends
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 1.8.1
  + No changelog available
* Tue Jan 31 2012 saschpe@suse.de
- Don't package INSTALL.txt and other docs twice
* Thu Jan 12 2012 saschpe@suse.de
- Spec file cosmetics
* Wed Jan 11 2012 toddrme2178@gmail.com
- Cleaned up spec file
- Renamed package from python-NetworkX to python-networkx to match the module name
* Thu Sep  8 2011 alinm.elena@gmail.com
- initial commit
* Fri Feb  6 2009 urs.beyerle@env.ethz.ch
- update to 0.99
* Thu Jun 26 2008 ti.eugene@gmail.com
- Initial build
